==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
var ToolActionNumberInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionNumberInputDescriptionMetadata, _super);
    function ToolActionNumberInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionNumberInputDescriptionMetadata.b = function (a) {
        if (ToolActionNumberInputDescriptionMetadata.a == null) {
            ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
        }
        if (a.g(ToolActionNumberInputDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionNumberInputDescriptionMetadata.a);
    };
    ToolActionNumberInputDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionNumberInputDescriptionMetadata.d = function (a) {
        ToolActionNumberInputDescriptionMetadata.b(a);
        a.u("ToolActionNumberInput", function () { return new ToolActionNumberInputDescription(); });
        a.t("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
    };
    ToolActionNumberInputDescriptionMetadata.$t = markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
}(Base));
export { ToolActionNumberInputDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
var ToolActionNumberInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionNumberInputDescriptionMetadata, _super);
    function ToolActionNumberInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionNumberInputDescriptionMetadata.b = function (a) {
        if (ToolActionNumberInputDescriptionMetadata.a == null) {
            ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
        }
        if (a.j(ToolActionNumberInputDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionNumberInputDescriptionMetadata.a);
    };
    ToolActionNumberInputDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionNumberInputDescriptionMetadata.d = function (a) {
        ToolActionNumberInputDescriptionMetadata.b(a);
        a.aa("ToolActionNumberInput", function () { return new ToolActionNumberInputDescription(); });
        a.z("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
    };
    ToolActionNumberInputDescriptionMetadata.$t = markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
}(Base));
export { ToolActionNumberInputDescriptionMetadata };
